@@ -23,7 +23,7 @@ import hardware
 from textlog import LogTrack
 import exputils
 
-import numpy
+import math, numpy, pygame
 import timing
 
 # method for setting realtime
@@ -305,11 +305,12 @@ def instructEnd(exitbutton = None, clk = None):
         line.unrequireLoaded()
 
     # update the screen, noting the timestamp
-    timestamp = inst_v.updateScreen()
+    timestamp = inst_v.updateScreen(clk)
 
     # tare the clock to the screen update time...
-    if clk:
-        clk.tare(timestamp)
+    # This is now done in the call to updateScreen
+    #if clk:
+    #    clk.tare(timestamp)
     
     if exitbutton:
         # if exitbutton is given, mark the end of the instructions in the log along with the exitbutton
@@ -988,7 +989,7 @@ def mathDistract(clk = None,
         if isCorrect == 1:
 	    # play the beep
             pTime = a.play(correctBeep,t=clk,doDelay=False)
-	    clk.tare(pTime[0])
+	    #clk.tare(pTime[0])
             #correctBeep.present(clk)
 
 	    # see if set color of text
@@ -1000,7 +1001,7 @@ def mathDistract(clk = None,
         else:
 	    # play the beep
             pTime = a.play(incorrectBeep,t=clk,doDelay=False)
-	    clk.tare(pTime[0])
+	    #clk.tare(pTime[0])
             #incorrectBeep.present(clk)
 
 	    # see if set color of text
@@ -1030,4 +1031,66 @@ def mathDistract(clk = None,
     mathlog.logMessage('STOP',timestamp)
 
     # tare the clock
-    clk.tare(timestamp)
+    # PBS: Why set the time back to when the last button was pressed?
+    #clk.tare(timestamp)
+
+class StatusBar:
+    """    
+    Manages two rectangles, one drawn inside the other.  The inner
+    rectange shrinks to show progress.  The recangles may be oriented
+    vertically, in which case progress occurs from bottom to top, or
+    horizontally, in which case progress occurs from right to left.
+    """
+    def __init__(self, width, height, startFraction=.5, totalSteps = 100, 
+		 fullColor=(255, 255, 255), emptyColor=(0, 0, 0), fringeWidthPx=2):
+	# do the full part
+	self.fullDim = (width, height)
+	self.fullColor = fullColor
+	
+	# do the empty part
+	self.emptyDim = [0, 0]
+	self.emptyOffset = [fringeWidthPx, fringeWidthPx]
+	self.emptyColor = emptyColor
+	self.fringeWidthPx = fringeWidthPx
+	
+	if width>height:
+	    # it's horizontal
+	    # assuming we fill from L to R
+	    self.fillDimension = 0	    
+	    self.staticDimension = 1
+	else:
+	    # it's vertical 
+	    # assuming we fill bottom to top
+	    self.fillDimension = 1
+	    self.staticDimension = 0
+    
+	self.emptyDim[self.fillDimension] = int(self.fullDim[self.fillDimension]*startFraction - fringeWidthPx)
+	self.emptyDim[self.staticDimension] = int(self.fullDim[self.staticDimension] - 2*fringeWidthPx)
+	if self.fillDimension==0:	    
+	    self.emptyOffset[self.fillDimension] = int(startFraction*
+						  (self.fullDim[self.fillDimension] - 2*fringeWidthPx) + fringeWidthPx)
+
+	self.pixelsPerStep = int(math.ceil((1-startFraction)*(self.fullDim[self.fillDimension] - 2*fringeWidthPx)/totalSteps))
+
+    def getImage(self):
+	# draw the larger rectangle
+	self.fullSurf = pygame.Surface(self.fullDim)
+	self.fullSurf.fill(self.fullColor)
+	# draw the smaller rectangle
+	self.emptySurf = pygame.Surface(tuple(self.emptyDim))
+	self.emptySurf.fill(self.emptyColor)
+	# superimpose the smaller one on the larger one
+	self.fullSurf.blit(self.emptySurf, tuple(self.emptyOffset))
+	return display.Image(hardware.graphics.LowImage(self.fullSurf))
+
+    def increment(self, coefficient=1):
+	# we always want to decrease emptyDim
+	if self.emptyDim[self.fillDimension] > coefficient*self.pixelsPerStep and \
+		self.emptyDim[self.fillDimension] < self.fullDim[self.fillDimension] - coefficient*self.pixelsPerStep:
+	    self.emptyDim[self.fillDimension] -= coefficient*self.pixelsPerStep
+
+	if self.fillDimension==0: 
+	    # if it's horizontal, we also want to increase emptyOffset
+	    if self.emptyOffset[self.fillDimension] < self.fullDim[self.fillDimension] - (self.fringeWidthPx + coefficeint*self.pixelsPerStep) and \
+		    self.emptyOffset[self.fillDimension] > coefficient*self.pixelsPerStep:
+		self.emptyOffset[self.fillDimension] += coefficient*self.pixelsPerStep
