@@ -114,15 +114,15 @@ class Shown:
 
         # calculate the anchors
         self.anchor = {}
-        self.anchor[CENTER] = (x + (width / 2), y - (height / 2))
-        self.anchor[NORTH] = (x + (width / 2), y - height)
-        self.anchor[NORTHEAST] = (x + width, y - height)
-        self.anchor[EAST] = (x + width, y - (height / 2))
-        self.anchor[SOUTHEAST] = (x + width, y)
-        self.anchor[SOUTH] = (x + (width / 2), y)
-        self.anchor[SOUTHWEST] = (x, y)
-        self.anchor[WEST] = (x, y - (height / 2))
-        self.anchor[NORTHWEST] = (x, y - height)
+        self.anchor[CENTER] = (x + (width / 2), y + (height / 2))
+        self.anchor[NORTH] = (x + (width / 2), y)
+        self.anchor[NORTHEAST] = (x + width, y)
+        self.anchor[EAST] = (x + width, y + (height / 2))
+        self.anchor[SOUTHEAST] = (x + width, y + height)
+        self.anchor[SOUTH] = (x + (width / 2), y + height)
+        self.anchor[SOUTHWEST] = (x, y + height)
+        self.anchor[WEST] = (x, y + (height / 2))
+        self.anchor[NORTHWEST] = (x, y)
 
 class ActiveShowable(Showable):
     """
@@ -882,17 +882,17 @@ class CompoundStimulus(Stimulus):
 	The form of the location field will depend on the value of
 	location-specification-mode.  
 
-	If location-specification-mode is 'ABS', then the third field
+	If location-specification-mode is 'ABS', then the fourth field
 	must be a 2-tuple containing the x- and y-coordinates (in
 	pixels) for displaying the the showable.
 
-	If location-specification-mode is 'PROP', then the third field
+	If location-specification-mode is 'PROP', then the fourth field
 	must be a 2-tuple containing the x- and y screen fractions for
 	displaying the the showable (e.g., (.6, .1) puts the showable
 	3/5ths of the way from the left edge, and 1/10th down from the
 	top edge).  
 
-	If location-specification-mode is 'REL', the third field must
+	If location-specification-mode is 'REL', the fourth field must
 	be a 2- (or 3-) tuple whose first dimension contains the one
 	of the relations: BELOW, ABOVE, LEFT, RIGHT, OVER.  The second
 	dimension of must be the text-label of another showable in the
@@ -901,17 +901,17 @@ class CompoundStimulus(Stimulus):
 	list can not be displayed using relative
 	location-specification.
 	
-	If location-specification-mode is 'ANCHOR', the third field
+	If location-specification-mode is 'ANCHOR', the fourth field
 	must be a 2- (up to 4-) tuple specifying first, the anchor on
 	the stim to show with CENTER, NORTH, NORTHWEST, ..., second,
 	the relative starting position as a 2-tuple of an (x,y)
 	location or the text-label and anchor point of a shown
 	('jubba',NORTHEAST).  You can optionally provide an offset in
-	proportional units or pixes as the third part of the tuple,
-	but the forth part must be set to False if you want to provide
+	proportional units or pixels as the third part of the tuple,
+	but the fourth part must be set to False if you want to provide
 	the offset in pixels and not proportional units.
 
-	('cool',stim,'ANCHOR',(CENTER,propToPixel(.25,.75),(.1,.15),True))
+	('cool',stim,'ANCHOR',(CENTER, propToPixel(.25,.75), (.1,.15), True))
 	
 	Example:
 	"""
@@ -957,7 +957,7 @@ class CompoundStimulus(Stimulus):
 		# show the showable with all the anchor info
 		self.showns[label] = v.showAnchored(stim, anchor, relPos, offset, isProp)
 	    else:
-		raise ValueError, "Invalid location specification mode " % specMode
+		raise ValueError, "Invalid location specification mode %s" % specMode
 
     def unshow(self):
 	v = VideoTrack.lastInstance()
@@ -1374,9 +1374,9 @@ class VideoTrack(textlog.LogTrack):
             t = timing.now()
         elif isinstance(t, exputils.PresentationClock):
             # if t is a PresentationClock, use the time from that clock
-	    clock = t
+            clock = t
             t = t.get()
-
+            
         # calculate the earliest allowable update time, based on the minimum frame duration
         mintime = self.last_updated[0] + self.minframeduration
         
@@ -1412,7 +1412,10 @@ class VideoTrack(textlog.LogTrack):
 
 	# see if we should tare the time 
 	if clock is not None:
-	    # we have a clock, so tare the clock to the presentation time
+	    # we have a clock
+            # accumulate errors
+            clock.accumulatedTimingError += r[0]-t
+            #so tare the clock to the presentation time
 	    clock.tare(r)
 
         # return the timestamp
