@@ -25,11 +25,14 @@ import mouse
 import display
 import sound
 import pool
+import exceptions
+
 from transarchive import Archive
 import random
 import time
 import weakref
 
+
 session = None
 
 # set up custom option types...
@@ -473,12 +476,24 @@ class PresentationClock:
     routines will advance the virtual clock to the moment of the input
     that the routine waited for.
     """
-    def __init__(self):
+    def __init__(self,correctAccumulatedErrors=False):
         """
         Create a PresentationClock set to the time of its creation.
         """
         # start the clock at the current time
         self.tare()
+
+        # save whether to correct the accumulated errors
+        self.correctAccumulatedErrors=correctAccumulatedErrors
+        
+        # keep track of the accumulated timing error in ms
+        # is in terms of (Actual - Expected)
+        self.resetAccumulatedTimingError()
+    def resetAccumulatedTimingError(self):
+        """
+        Reset the accumulated timing error to zero.
+        """
+        self.accumulatedTimingError = 0
     def tare(self, t = None):
         """
         Set the clock to the current time, or to the time specified.
@@ -496,7 +511,7 @@ class PresentationClock:
         else:
             # otherwise, set the time to the given paramenter (in milliseconds)
             self.virtualtime = t
-    def delay(self, milliseconds, jitter = None):
+    def delay(self, milliseconds, jitter = None, resolveTimingError=False):
         """
         Advance the clock by the number of milliseconds given.
         Optionally add a random amount of time up to the given jitter
@@ -508,20 +523,56 @@ class PresentationClock:
             clock is advanced a random number of milliseconds between 0
             and the value of this parameter, in addition to the clock
             advance due to the milliseconds parameter.
+            
+          resolveTimingError- Optional argument that defaults to
+            False.  This will adjust the requested milliseconds by the
+            accumulated error from previous timedCalls with this
+            clock.  Accumulated error can occur in a number of ways.
+            For example, if you requested an updateScreen to occur at
+            a specific time t based on the presentation clock's
+            virtual time, but the updateScreen actually occurred at
+            time t+5 because it is timed to the screen refresh, you
+            would have an accumulated error of 5ms.  In this case, you
+            would need to subtract 5ms from the milliseconds delay to
+            make sure that the next stimulus comes on the screen when
+            you desire.
           
         """
         if jitter:
             # if jitter is given, translate this into a call to jitter
-            self.jitter(milliseconds, milliseconds + jitter)
+            # and set actual milliseconds used
+            milliseconds = self.jitter(milliseconds, milliseconds + jitter, resolveTimingError)
         else:
             # otherwise, add milliseconds to the virtual time
+            # see if we must resolve the timing error
+            if self.correctAccumulatedErrors or resolveTimingError:
+                # adjust the milliseconds and reset the accumulatedTimingError
+                milliseconds -= self.accumulatedTimingError
+                if milliseconds < 0:
+                    self.accumulatedTimingError = -milliseconds
+                    milliseconds = 0
+                    exceptions.eplWarn("Unable to account for %dms of timing error." % 
+                                       (self.accumulatedTimingError))
+                else:
+                    self.accumulatedTimingError = 0
+            # extend the virtual time        
             self.virtualtime += milliseconds
-    def jitter(self, low_milliseconds, high_milliseconds = None):
+
+        # return the milliseconds (to see if changed)
+        return milliseconds
+    def jitter(self, low_milliseconds, high_milliseconds = None, resolveTimingError=False):
         """
         Advances the clock by a random number of milliseconds.
 
         INPUT ARGS:
-          ms1 & ms2-  If one argument is specified, delay a random amount of time between 0 and the value of the parameter (in milliseconds).  if two parameters, delay a random amount of time between the values of the first and second parameters (in milliseconds)
+        
+          ms1 & ms2- If one argument is specified, delay a random
+            amount of time between 0 and the value of the parameter
+            (in milliseconds).  if two parameters, delay a random
+            amount of time between the values of the first and second
+            parameters (in milliseconds)
+
+          resolveTimingError- see the help for delay.
         """
         if high_milliseconds is None:
             # if called with only one parameter, delay a random amount of time between 0 and the value of the parameter (in milliseconds)
@@ -530,11 +581,8 @@ class PresentationClock:
             # if two parameters, delay a random amount of time between the values of the first and second parameters (in milliseconds)
             t = random.randint(low_milliseconds, high_milliseconds)
 
-        # do the delay
-        self.delay(t)
-
         # return the amount of time actually delayed
-        return t
+        return self.delay(t,resolveTimingError=resolveTimingError)
     def get(self):
         """
         Retrieves the clock's virtual time.
