@@ -86,10 +86,7 @@ setGammaRamp = graphics.setGammaRamp
 if sys.platform=='darwin':
     AWCard = eeg.awCard
 else:
-    EEGOpenPort = eeg.openPort
-    EEGClosePort = eeg.closePort
-    EEGSetState = eeg.setState
-    EEGSetSignal = eeg.setSignal
+    Parallel = eeg.Parallel
     EEGShmAttached = eeg.shmAttached
     EEGShmAttach = eeg.shmAttach
     EEGShmDetach = eeg.shmDetach
@@ -97,7 +94,6 @@ else:
     EEGRecStop = eeg.recStop
     EEGGetOffset = eeg.getOffset
     EPLScalpEEGException = eeg.EPLScalpEEGException
-    EPLPulseEEGException = eeg.EPLPulseEEGException
 
 # Sound Features
 EPLSound = sound.EPLSound
