@@ -513,6 +513,9 @@ class AudioTrack(textlog.LogTrack):
           soundClip- AudioClip object of the sound to be played
           t- Optional PresentationClock for timing.
           ampFactor- Optional amplification of sound.  (default value is 1)
+          doDelay- Optionally do not tare and move the presentation clock
+            forward.  Defaults to True (moving the clock forward)
+          
         OUTPUT ARGS:
           timestamp- time and latency when sound playing began.
           
@@ -558,8 +561,11 @@ class AudioTrack(textlog.LogTrack):
 						       soundClip.snd[0:firstbytes],
 						       len(soundClip.snd[0:firstbytes])/self.eplsound.FORMAT_SIZE,
 						       0, ampFactor)
-
+    
             if doDelay:
+                # accumulate the error
+                clk.accumulatedTimingError += timeInterval[0]-t
+                # tare the clock and delay the proper amount
                 clk.tare(timeInterval[0])
                 clk.delay(soundClip.getDuration())
 
